@@ -258,17 +258,15 @@ f = TexturedRenderer(vc=A, camera=U, f=m.f, bgcolor=[0.,0.,0.],
 translation, rotation = ch.array([0,0,4]), ch.zeros(3)                          
 f.v = translation + V.dot(Rodrigues(rotation))                                  
                                                                                 
-try:
-    observed = load_image('earth_observed.jpg')
-except:
-    observed = f.r 
-    translation[:] = translation.r + np.random.rand(3)*.2
-    rotation[:] = rotation.r + np.random.rand(3)*.2
-    A.components[1:] = 0
+observed = f.r 
+translation[:] = translation.r + np.random.rand(3)*.2
+rotation[:] = rotation.r + np.random.rand(3)*.2
+A.components[1:] = 0
 
 # Create the energy
 difference = f - observed
-E = gaussian_pyramid(difference, n_levels=6, normalization='SSE')               
+E = gaussian_pyramid(difference, n_levels=6, as_list=True)[-3:]
+E = ch.concatenate([e.ravel() for e in E])
 
 plt.ion()
 global cb
@@ -285,8 +283,13 @@ def cb(_):
 light_parms = A.components     
 print 'OPTIMIZING TRANSLATION'                                                 
 ch.minimize({'energy': E}, x0=[translation], callback=lambda _ : cb(difference)) 
+
 print 'OPTIMIZING TRANSLATION, ROTATION, AND LIGHT PARMS'                                                 
 ch.minimize({'energy': E}, x0=[translation, rotation, light_parms], callback=cb) 
+
+E = gaussian_pyramid(difference, n_levels=6, normalization='size')
+ch.minimize({'energy': E}, x0=[translation, rotation, light_parms], callback=cb) 
+
 """
 
 
